@@ -132,6 +132,29 @@ def class_name(obj_type: str) -> str:
     return util.Camelize(obj_type) + "MetricType"
 
 
+def generate_build_date(date: Optional[str]) -> str:
+    """
+    Generate the build timestamp.
+    """
+
+    ts = util.build_date(date)
+
+    data = [
+        str(ts.year),
+        # In Java the first month of the year in calendars is JANUARY which is 0.
+        # In Python it's 1-based
+        str(ts.month - 1),
+        str(ts.day),
+        str(ts.hour),
+        str(ts.minute),
+        str(ts.second),
+    ]
+    components = ", ".join(data)
+
+    # DatetimeMetricType takes a `Calendar` instance.
+    return f'Calendar.getInstance(TimeZone.getTimeZone("GMT+0")).also {{ cal -> cal.set({components}) }}'  # noqa
+
+
 def output_gecko_lookup(
     objs: metrics.ObjectTree, output_dir: Path, options: Optional[Dict[str, Any]] = None
 ) -> None:
@@ -249,6 +272,11 @@ def output_kotlin(
         - `with_buildinfo`: If "true" a `GleanBuildInfo.kt` file is generated.
           Otherwise generation of that file is skipped.
           Defaults to "true".
+        - `build_date`: If set to `0` a static unix epoch time will be used.
+                        If set to a ISO8601 datetime string (e.g. `2022-01-03T17:30:00`)
+                        it will use that date.
+                        Other values will throw an error.
+                        If not set it will use the current date & time.
     """
     if options is None:
         options = {}
@@ -257,6 +285,7 @@ def output_kotlin(
     glean_namespace = options.get("glean_namespace", "mozilla.components.service.glean")
     namespace_package = namespace[: namespace.rfind(".")]
     with_buildinfo = options.get("with_buildinfo", "true").lower() == "true"
+    build_date = options.get("build_date", None)
 
     # Write out the special "build info" object
     template = util.get_jinja2_template(
@@ -264,6 +293,7 @@ def output_kotlin(
     )
 
     if with_buildinfo:
+        build_date = generate_build_date(build_date)
         # This filename needs to start with "Glean" so it can never clash with a
         # metric category
         with (output_dir / "GleanBuildInfo.kt").open("w", encoding="utf-8") as fd:
@@ -272,6 +302,7 @@ def output_kotlin(
                     namespace=namespace,
                     namespace_package=namespace_package,
                     glean_namespace=glean_namespace,
+                    build_date=build_date,
                 )
             )
             fd.write("\n")
