@@ -110,7 +110,7 @@ def test_parser_schema_violation():
         the given schemas
         'gleantest.with.way.too.long.category.name' is too long
         'gleantest.with.way.too.long.category.name' is not one of
-        ['$schema']
+        ['$schema', '$tags']
         """,
         """
         ```
@@ -558,9 +558,25 @@ def test_send_in_pings_restrictions():
     all_metrics = parser.parse_objects(ROOT / "data" / "invalid-ping-names.yaml")
     errors = list(all_metrics)
     assert len(errors) == 1
+
     assert "'invalid_ping_name' does not match" in errors[0]
 
 
+def test_tags():
+    """Tests that tags can be specified."""
+    all_metrics = parser.parse_objects(ROOT / "data" / "metric-with-tags.yaml")
+    errors = list(all_metrics)
+
+    assert errors == []
+    assert len(all_metrics.value) == 1
+    assert set(all_metrics.value["telemetry"]["client_id"].metadata.keys()) == set(
+        ["tags"]
+    )
+    assert set(all_metrics.value["telemetry"]["client_id"].metadata["tags"]) == set(
+        ["banana", "apple", "global_tag"]
+    )
+
+
 def test_custom_expires():
     contents = [
         {
